Description Usage Arguments Value
View source: R/replace_code_chunks.R
Conditionally replace code in a block of lines
1 | replace_block(block, replace_flags, replacement, comment)
|
block |
A character vector of lines from an Rmarkdown document that are either a section of text or a code chunk. |
replace_flags |
A character vector of code chunk options that if set to TRUE will have their code replaced. |
replacement |
A character vector that code chunks will be replaced with, one element per line. |
comment |
TRUE or FALSE; whether to include comments. |
The input code chunk or text, modified only if it is a code chunk with one of the replace_flags in its options
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.